Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( NO_AUTH_HEADER = status.Errorf(codes.InvalidArgument, "No authheader provided") PERMISSION_DENIED = status.Errorf(codes.PermissionDenied, "Permission Denied") INTERNAL_ERROR = status.Errorf(codes.Internal, "Unkonwn Internal failure") POSTGRES_CONNECTION_ERROR = status.Errorf(codes.Internal, "Cannot connect to postgres") )
Functions ¶
func CreateUser ¶
func CreateUser(ctx context.Context, in *authmaster.CreateUserRequest) (*authmaster.CreateUserResponse, error)
func HandleTest ¶
func HandleTest(ctx context.Context) (*authmaster.TestAuthResponse, error)
func Login ¶
func Login(ctx context.Context, in *authmaster.LoginRequest) (*authmaster.LoginResponse, error)
currently we have a race on checking the password and making a new token. This is fine for now since user data is completely immutable, but in the future if we want to support users changing their passwords, we'll have to fix this.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.